<?php declare(strict_types=1);

namespace EuKit\Base\Services;

use EuKit\Base\Interfaces\ThemeServiceStartup;
use Infomaker\Everyware\Base\OpenContent\OpenContentProvider;
use Infomaker\Everyware\Base\PropertyMapConfig;
use Infomaker\Everyware\Base\PropertyMapper;

/**
 * Class ContentProviderServiceStartup
 * @package EuKit\Base\Services
 */
class ContentProviderServiceStartup implements ThemeServiceStartup
{
    /**
     * @var PropertyMapConfig
     */
    private $config;

    /**
     * @var PropertyMapper
     */
    private $propertyMapper;

    public function __construct(PropertyMapConfig $config)
    {
        $this->config = $config;
        $this->propertyMapper = new PropertyMapper($this->config);
    }

    public function getContentTypeProperties(iterable $contentTypes): array
    {
        $contentProperties = [];

        foreach ($contentTypes as $contentType) {
            $contentProperties[$contentType] = $this->propertyMapper->requiredProperties($contentType);
        }

        return $contentProperties;
    }

    public function setup(): void
    {
        $contentProperties = $this->getContentTypeProperties([
            'Article',
            'Concept',
            'List'
        ]);

        foreach ($contentProperties as $contentType => $properties) {
            OpenContentProvider::setupNotifierProperties($contentType, $properties);
        }

        OpenContentProvider::setupPropertyMapper($this->config);
        OpenContentProvider::setupDefaultSearchProperties($contentProperties['Article']);
        OpenContentProvider::setupRequiredSearchProperties([]);
    }
}
